@@ -1,7 +1,7 @@
 package Perinci::CmdLine;
 
-our $DATE = '2014-10-03'; # DATE
-our $VERSION = '1.32'; # VERSION
+our $DATE = '2014-10-14'; # DATE
+our $VERSION = '1.33'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -845,7 +845,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.32 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2014-10-03.
+This document describes version 1.33 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2014-10-14.
 
 =head1 SYNOPSIS
 
@@ -855,8 +855,20 @@ See L<Perinci::CmdLine::Manual::Examples>.
 
 See L<Perinci::CmdLine::Manual>.
 
+Screenshots:
+
 =for Pod::Coverage ^(.+)$
 
+=begin HTML
+
+<p><img src="http://blogs.perl.org/users/perlancar/screenshot-pericmd-help.jpg" /><br />Autogenerated help message
+
+<p><img src="http://blogs.perl.org/users/perlancar/screenshot-pericmd-help_verbose.jpg" /><br />Autogenerated help message (verbose mode)
+
+<p><img src="http://blogs.perl.org/users/perlancar/progany-tpc.jpg" /><br />Progress bar
+
+=end HTML
+
 =head1 REQUEST KEYS
 
 See also L<Perinci::CmdLine::Base>. Extra stuffs put by this module to the C<$r>
@@ -962,7 +974,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine>.
 
 =head1 BUGS
 
